@@ -19,6 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "about.h"
 #include "calendar.h"
 #include "i18n.h"
 #include "calendar_print.h"
@@ -40,6 +41,28 @@
 #include "check_events.h"
 #include "calendar_moon.h"
 #include "stock_icons.h"
+#include "preferences_gui.h"
+
+/*------------------------------------------------------------------------------*/
+
+static void
+show_about_window_cb (GtkWidget *widget, GUI *appGUI)
+{
+	GtkWidget *window = opt_create_about_window (appGUI);
+	gtk_widget_show (window);
+}
+
+/*------------------------------------------------------------------------------*/
+
+static void
+show_preferences_window_cb (GtkWidget *widget, GUI *appGUI)
+{
+	appGUI->opt->window = opt_create_preferences_window (appGUI);
+	gtk_widget_show (appGUI->opt->window);
+
+	gint page = gtk_notebook_page_num (GTK_NOTEBOOK (appGUI->opt->notebook), appGUI->opt->calendar);
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->opt->notebook), page);
+}
 
 /*------------------------------------------------------------------------------*/
 
@@ -73,6 +96,8 @@ gint i, days;
 	tmpdate = g_date_new_dmy (1, g_date_get_month (date), g_date_get_year (date));
 	g_return_if_fail (tmpdate != NULL);
 
+	if (appGUI->calendar_only == TRUE) return;
+
 	gui_calendar_clear_marks (GUI_CALENDAR (appGUI->cal->calendar), DAY_NOTE_MARK);
 	gui_calendar_clear_marks (GUI_CALENDAR (appGUI->cal->calendar), EVENT_MARK);
 	gui_calendar_clear_marks (GUI_CALENDAR (appGUI->cal->calendar), BIRTHDAY_MARK);
@@ -209,6 +234,8 @@ guint month, year;
 guint i, days;
 GDate *tmpdate;
 
+	if (appGUI->calendar_only == TRUE) return;
+
 	tmpdate = g_date_new_julian (g_date_get_julian (date));
 
 	month = g_date_get_month (tmpdate) - 1;
@@ -245,6 +272,8 @@ mark_events (GtkWidget *calendar, guint month, guint year, GUI *appGUI)
 	guint32 julian;
 	guint i, days;
 
+	if (appGUI->calendar_only == TRUE) return;
+
 	gui_calendar_select_month (GUI_CALENDAR (calendar), month, year);
 	gui_calendar_select_day (GUI_CALENDAR (calendar), 1);
 	gui_calendar_clear_marks (GUI_CALENDAR (calendar), DAY_NOTE_MARK);
@@ -272,8 +301,12 @@ update_aux_calendars (GUI *appGUI)
 gchar buffer[BUFFER_SIZE];
 GDate *tmpdate;
 
-	if (appGUI->calendar_only == TRUE || config.enable_auxilary_calendars == FALSE ||
-	    config.auxilary_calendars_state == FALSE) return;
+	if (appGUI->calendar_only == TRUE) return;
+
+	if (!config.gui_layout) {
+		if (appGUI->calendar_only == TRUE || config.enable_auxilary_calendars == FALSE ||
+			config.auxilary_calendars_state == FALSE) return;
+	}
 
 	tmpdate = g_date_new ();
 	g_return_if_fail (tmpdate != NULL);
@@ -876,7 +909,7 @@ cal_set_date (GDate *date, GUI *appGUI)
 	gui_calendar_select_day (GUI_CALENDAR (appGUI->cal->calendar), 1);     /* Trick: always select valid day number */
 	gui_calendar_select_month (GUI_CALENDAR (appGUI->cal->calendar), g_date_get_month (date) - 1, g_date_get_year (date));
 	gui_calendar_select_day (GUI_CALENDAR (appGUI->cal->calendar), g_date_get_day (date));
-	gtk_label_set_text (GTK_LABEL (appGUI->cal->date_label), utl_get_date_name (date));
+	gtk_label_set_text (GTK_LABEL (appGUI->cal->date_label), utl_get_date_name_format (date, config.date_header_format));
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1143,18 +1176,14 @@ calendar_store_note (GUI *appGUI)
 /*------------------------------------------------------------------------------*/
 
 void
-calendar_day_selected_cb (GuiCalendar *calendar, gpointer user_data)
+calendar_day_selected_cb (GuiCalendar *calendar, GUI *appGUI)
 {
-GDate *prev_date;
-
-	GUI *appGUI = (GUI *) user_data;
-	prev_date = g_date_new_julian (g_date_get_julian (appGUI->cal->date));
-	g_return_if_fail (prev_date != NULL);
+	GDate *prev_date = g_date_new_julian (g_date_get_julian (appGUI->cal->date));
 
 	if (appGUI->cal->dont_update == FALSE)
 		gui_calendar_get_gdate (GUI_CALENDAR (calendar), appGUI->cal->date);
 
-	gtk_label_set_text (GTK_LABEL (appGUI->cal->date_label), utl_get_date_name (appGUI->cal->date));
+	gtk_label_set_text (GTK_LABEL (appGUI->cal->date_label), utl_get_date_name_format (appGUI->cal->date, config.date_header_format));
 
 	if (appGUI->cal->dont_update == FALSE) {
 		if (appGUI->calendar_only == FALSE) {
@@ -1166,6 +1195,8 @@ GDate *prev_date;
 		}
 	}
 
+	g_date_free (prev_date);
+
 	if (appGUI->calendar_only == FALSE) {
 		/* enable/disable 'select day color' popup entry */
 		if (cal_check_note (g_date_get_julian (appGUI->cal->date), appGUI) == TRUE) {
@@ -1476,7 +1507,12 @@ date_selected_cb (GtkCalendar *calendar, gpointer user_data)
 	GUI *appGUI = (GUI *)user_data;
 	GDate *date = g_date_new ();
 
-    if (gtk_expander_get_expanded (GTK_EXPANDER(appGUI->cal->aux_cal_expander)) == FALSE) return;
+	if (!config.gui_layout) {
+        if (gtk_expander_get_expanded (GTK_EXPANDER(appGUI->cal->aux_cal_expander)) == FALSE) {
+			g_date_free (date);
+			return;
+		}
+	}
 
 	gui_calendar_get_gdate (GUI_CALENDAR (calendar), date);
 	cal_jump_to_date (date, appGUI);
@@ -1491,6 +1527,8 @@ gui_create_calendar(GtkWidget *notebook, GUI *appGUI) {
 
 GtkWidget       *vbox1;
 GtkWidget       *vbox2;
+GtkWidget       *vbox3;
+GtkWidget       *hbox1 = NULL;
 GtkWidget       *hbox2;
 GtkWidget       *hbox3;
 GtkWidget       *eventbox;
@@ -1503,7 +1541,6 @@ GtkUIManager    *uim_widget = NULL;
 GError          *error = NULL;
 GtkActionGroup  *action_group = NULL;
 GtkWidget       *note_scrolledwindow;
-GtkWidget       *calendars_table;
 #ifdef TASKS_ENABLED
 GtkWidget       *popup_menu_add_task_entry;
 #endif  /* TASKS_ENABLED */
@@ -1527,35 +1564,40 @@ const gchar *ui_info =
 "    <toolitem name=\"next_day\" action=\"next_day\" />\n"
 "    <toolitem name=\"next_month\" action=\"next_month\" />\n"
 "    <toolitem name=\"next_year\" action=\"next_year\" />\n"
-"    <separator name=\"sep1\" />\n"
+"    <separator/>\n"
 "    <toolitem name=\"jump_to_date\" action=\"jump_to_date\" />\n"
 "    <toolitem name=\"full_year\" action=\"full_year\" />\n"
 "    <toolitem name=\"date_calc\" action=\"date_calc\" />\n"
 #ifdef PRINTING_SUPPORT
 "    <toolitem name=\"print\" action=\"print\" />\n"
 #endif /* PRINTING_SUPPORT */
-"    <separator name=\"sep2\" />\n"
+"    <separator/>\n"
 "    <toolitem name=\"edit_note\" action=\"edit_note\" />\n"
+"    <separator expand=\"true\" />\n"
+"    <toolitem name=\"preferences\" action=\"preferences\" />\n"
+"    <toolitem name=\"about\" action=\"about\" />\n"
 "  </toolbar>\n";
 
 GtkActionEntry entries[] = {
-    { "previous_year", OSMO_STOCK_PREV_YEAR, _("Previous year"), NULL, _("Previous year"), NULL},
-    { "previous_month", OSMO_STOCK_PREV_MONTH, _("Previous month"), NULL, _("Previous month"), NULL},
-    { "previous_day", OSMO_STOCK_PREV_DAY, _("Previous day"), NULL, _("Previous day"), NULL},
-    { "today", OSMO_STOCK_TODAY, _("Today"), NULL, _("Today"), NULL},
-    { "next_day", OSMO_STOCK_NEXT_DAY, _("Next day"), NULL, _("Next day"), NULL},
-    { "next_month", OSMO_STOCK_NEXT_MONTH, _("Next month"), NULL, _("Next month"), NULL},
-    { "next_year", OSMO_STOCK_NEXT_YEAR, _("Next year"), NULL, _("Next year"), NULL},
-    { "jump_to_date", OSMO_STOCK_JUMPTO, _("Jump to date"), NULL, _("Jump to date"), NULL},
-    { "full_year", OSMO_STOCK_FULLYEAR, _("Full-year calendar"), NULL, _("Full-year calendar"), NULL},   
+    { "previous_year", OSMO_STOCK_PREV_YEAR, _("Previous year"), NULL, _("Previous year"), G_CALLBACK(calendar_btn_prev_year_cb)},
+    { "previous_month", OSMO_STOCK_PREV_MONTH, _("Previous month"), NULL, _("Previous month"), G_CALLBACK(calendar_btn_prev_month_cb)},
+    { "previous_day", OSMO_STOCK_PREV_DAY, _("Previous day"), NULL, _("Previous day"), G_CALLBACK(calendar_btn_prev_day_cb)},
+    { "today", OSMO_STOCK_TODAY, _("Today"), NULL, _("Today"), G_CALLBACK(calendar_btn_today_cb)},
+    { "next_day", OSMO_STOCK_NEXT_DAY, _("Next day"), NULL, _("Next day"), G_CALLBACK(calendar_btn_next_day_cb)},
+    { "next_month", OSMO_STOCK_NEXT_MONTH, _("Next month"), NULL, _("Next month"), G_CALLBACK(calendar_btn_next_month_cb)},
+    { "next_year", OSMO_STOCK_NEXT_YEAR, _("Next year"), NULL, _("Next year"), G_CALLBACK(calendar_btn_next_year_cb)},
+    { "jump_to_date", OSMO_STOCK_JUMPTO, _("Jump to date"), NULL, _("Jump to date"), G_CALLBACK(calendar_create_jumpto_window_cb)},
+    { "full_year", OSMO_STOCK_FULLYEAR, _("Full-year calendar"), NULL, _("Full-year calendar"), G_CALLBACK(calendar_create_fullyear_window_cb)},   
 #ifdef PRINTING_SUPPORT
-    { "print", OSMO_STOCK_PRINT, _("Print calendar"), NULL, _("Print calendar"), NULL },
+    { "print", OSMO_STOCK_PRINT, _("Print calendar"), NULL, _("Print calendar"), G_CALLBACK(calendar_print_cb)},
 #endif /* PRINTING_SUPPORT */
-    { "date_calc", OSMO_STOCK_CALCULATOR, _("Date calculator"), NULL, _("Date calculator"), NULL},
+    { "date_calc", OSMO_STOCK_CALCULATOR, _("Date calculator"), NULL, _("Date calculator"), G_CALLBACK(calendar_create_datecalc_window_cb)},
+	{ "preferences", OSMO_STOCK_PREFERENCES, _("Preferences"), NULL, _("Preferences"), G_CALLBACK(show_preferences_window_cb)},
+	{ "about", OSMO_STOCK_ABOUT, _("About"), NULL, _("About"), G_CALLBACK (show_about_window_cb)},
 };
 
 GtkToggleActionEntry t_entries[] = {
-    { "edit_note", OSMO_STOCK_EDIT_NOTE, _("Toggle day note panel"), NULL, _("Toggle day note panel"), NULL, FALSE }
+    { "edit_note", OSMO_STOCK_EDIT_NOTE, _("Toggle day note panel"), NULL, _("Toggle day note panel"), G_CALLBACK(calendar_edit_note_cb), FALSE }
 };
 
 guint n_entries = G_N_ELEMENTS (entries);
@@ -1577,8 +1619,8 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
     /*-------------------------------------------------------------------------------------*/
 
     action_group = gtk_action_group_new ("_actions");
-    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
-    gtk_action_group_add_toggle_actions (action_group, t_entries, n_t_entries, NULL);
+    gtk_action_group_add_actions (action_group, entries, n_entries, appGUI);
+    gtk_action_group_add_toggle_actions (action_group, t_entries, n_t_entries, appGUI);
     gtk_action_group_set_sensitive(action_group, TRUE);
 
     uim_widget = gtk_ui_manager_new ();
@@ -1602,53 +1644,41 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
 #ifdef PRINTING_SUPPORT
         gtk_widget_hide (gtk_ui_manager_get_widget (uim_widget, "/toolbar/print"));
 #endif /* PRINTING_SUPPORT */
+        gtk_widget_hide (gtk_ui_manager_get_widget (uim_widget, "/toolbar/preferences"));
+        gtk_widget_hide (gtk_ui_manager_get_widget (uim_widget, "/toolbar/about"));
     }
 
-    /*-------------------------------------------------------------------------------------*/
-    /* assign callbacks */
-
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/previous_year")), "clicked", 
-                      G_CALLBACK(calendar_btn_prev_year_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/next_year")), "clicked", 
-                      G_CALLBACK(calendar_btn_next_year_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/previous_month")), "clicked", 
-                      G_CALLBACK(calendar_btn_prev_month_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/next_month")), "clicked", 
-                      G_CALLBACK(calendar_btn_next_month_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/previous_day")), "clicked", 
-                      G_CALLBACK(calendar_btn_prev_day_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/next_day")), "clicked", 
-                      G_CALLBACK(calendar_btn_next_day_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/today")), "clicked", 
-                      G_CALLBACK(calendar_btn_today_cb), appGUI);
-
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/jump_to_date")), "clicked", 
-                      G_CALLBACK(calendar_create_jumpto_window_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/full_year")), "clicked", 
-                      G_CALLBACK(calendar_create_fullyear_window_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/date_calc")), "clicked", 
-                      G_CALLBACK(calendar_create_datecalc_window_cb), appGUI);
-#ifdef PRINTING_SUPPORT
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/print")), "clicked", 
-                      G_CALLBACK(calendar_print_cb), appGUI);
-#endif /* PRINTING_SUPPORT */
-
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/edit_note")), "toggled", 
-                      G_CALLBACK(calendar_edit_note_cb), appGUI);
-
     /*-------------------------------------------------------------------------------------*/
 
     vbox2 = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox2);
     gtk_box_pack_start (GTK_BOX (vbox1), vbox2, TRUE, TRUE, 0);
 
+	if (config.gui_layout && appGUI->calendar_only == FALSE) {
+		hbox1 = gtk_hbox_new (FALSE, 6);
+		gtk_widget_show (hbox1);
+		gtk_box_pack_start (GTK_BOX (vbox2), hbox1, TRUE, TRUE, 0);
+	}
+
+	vbox3 = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox3);
+    if (appGUI->calendar_only == TRUE) {
+			gtk_box_pack_start (GTK_BOX (vbox2), vbox3, TRUE, TRUE, 0);
+	} else {
+		if (!config.gui_layout) {
+			gtk_box_pack_start (GTK_BOX (vbox2), vbox3, TRUE, TRUE, 0);
+		} else {
+			gtk_box_pack_start (GTK_BOX (hbox1), vbox3, FALSE, FALSE, 0);
+		}
+	}
+
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_box_pack_start (GTK_BOX (vbox2), hseparator, FALSE, FALSE, 6);
+    gtk_box_pack_start (GTK_BOX (vbox3), hseparator, FALSE, FALSE, 6);
 
     eventbox = gtk_event_box_new ();
     gtk_widget_show (eventbox);
-    gtk_box_pack_start (GTK_BOX (vbox2), eventbox, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox3), eventbox, FALSE, FALSE, 0);
   	g_signal_connect (G_OBJECT(eventbox), "button_press_event", G_CALLBACK(click_handler_cb), appGUI);
 
     hbox2 = gtk_hbox_new (FALSE, 0);
@@ -1713,7 +1743,7 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_box_pack_start (GTK_BOX (vbox2), hseparator, FALSE, FALSE, 6);
+    gtk_box_pack_start (GTK_BOX (vbox3), hseparator, FALSE, FALSE, 6);
 
     appGUI->cal->calendar = gui_calendar_new ();
     gtk_widget_show (appGUI->cal->calendar);
@@ -1721,7 +1751,7 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
     GTK_WIDGET_UNSET_FLAGS(appGUI->cal->calendar, GTK_CAN_FOCUS);
     gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->calendar), config.display_options);
     gtk_widget_modify_font (GTK_WIDGET(appGUI->cal->calendar), appGUI->cal->fd_cal_font);
-    gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->calendar, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox3), appGUI->cal->calendar, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (appGUI->cal->calendar), "day-selected", 
                       G_CALLBACK (calendar_day_selected_cb), appGUI);
     g_signal_connect (G_OBJECT (appGUI->cal->calendar), "day-selected-double-click", 
@@ -1747,36 +1777,44 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
 
     if (appGUI->calendar_only == FALSE) {
 
-        appGUI->cal->aux_cal_expander = gtk_expander_new (_("Previous and next month"));
-        GTK_WIDGET_UNSET_FLAGS(appGUI->cal->aux_cal_expander, GTK_CAN_FOCUS);
-        gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->aux_cal_expander, FALSE, FALSE, 0);
+		if (!config.gui_layout) {
+			appGUI->cal->aux_cal_expander = gtk_expander_new (_("Previous and next month"));
+			GTK_WIDGET_UNSET_FLAGS(appGUI->cal->aux_cal_expander, GTK_CAN_FOCUS);
+			gtk_box_pack_start (GTK_BOX (vbox3), appGUI->cal->aux_cal_expander, FALSE, FALSE, 0);
+		}
 
-        if (config.enable_auxilary_calendars == TRUE) {
-            gtk_widget_show (appGUI->cal->aux_cal_expander);
+        appGUI->cal->aux_calendars_table = gtk_table_new (2, 2, FALSE);
+		if (!config.gui_layout) {
+            gtk_container_add (GTK_CONTAINER (appGUI->cal->aux_cal_expander), appGUI->cal->aux_calendars_table);
+		} else {
+			gtk_box_pack_start (GTK_BOX (vbox3), appGUI->cal->aux_calendars_table, FALSE, FALSE, 0);
+		}
+        gtk_table_set_row_spacings (GTK_TABLE (appGUI->cal->aux_calendars_table), 4);
+        gtk_table_set_col_spacings (GTK_TABLE (appGUI->cal->aux_calendars_table), 4);
+
+		if (config.enable_auxilary_calendars == TRUE) {
+			if (!config.gui_layout) {
+                gtk_widget_show (appGUI->cal->aux_cal_expander);
+			}
+            gtk_widget_show (appGUI->cal->aux_calendars_table);
         }
 
-        calendars_table = gtk_table_new (2, 2, FALSE);
-        gtk_widget_show (calendars_table);
-        gtk_container_add (GTK_CONTAINER (appGUI->cal->aux_cal_expander), calendars_table);
-        gtk_table_set_row_spacings (GTK_TABLE (calendars_table), 4);
-        gtk_table_set_col_spacings (GTK_TABLE (calendars_table), 4);
-
         appGUI->cal->prev_month_label = gtk_label_new ("");
         gtk_widget_show (appGUI->cal->prev_month_label);
-        gtk_table_attach (GTK_TABLE (calendars_table), appGUI->cal->prev_month_label, 0, 1, 0, 1,
+        gtk_table_attach (GTK_TABLE (appGUI->cal->aux_calendars_table), appGUI->cal->prev_month_label, 0, 1, 0, 1,
                           (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                           (GtkAttachOptions) (0), 0, 0);
 
         appGUI->cal->next_month_label = gtk_label_new ("");
         gtk_widget_show (appGUI->cal->next_month_label);
-        gtk_table_attach (GTK_TABLE (calendars_table), appGUI->cal->next_month_label, 1, 2, 0, 1,
+        gtk_table_attach (GTK_TABLE (appGUI->cal->aux_calendars_table), appGUI->cal->next_month_label, 1, 2, 0, 1,
                           (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                           (GtkAttachOptions) (0), 0, 0);
 
         appGUI->cal->calendar_prev = gui_calendar_new ();
         gtk_widget_show (appGUI->cal->calendar_prev);
         GTK_WIDGET_UNSET_FLAGS(appGUI->cal->calendar_prev, GTK_CAN_FOCUS);
-        gtk_table_attach (GTK_TABLE (calendars_table), appGUI->cal->calendar_prev, 0, 1, 1, 2,
+        gtk_table_attach (GTK_TABLE (appGUI->cal->aux_calendars_table), appGUI->cal->calendar_prev, 0, 1, 1, 2,
                           (GtkAttachOptions) (GTK_FILL),
                           (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
         gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->calendar_prev), 
@@ -1798,7 +1836,7 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
         appGUI->cal->calendar_next = gui_calendar_new ();
         gtk_widget_show (appGUI->cal->calendar_next);
         GTK_WIDGET_UNSET_FLAGS(appGUI->cal->calendar_next, GTK_CAN_FOCUS);
-        gtk_table_attach (GTK_TABLE (calendars_table), appGUI->cal->calendar_next, 1, 2, 1, 2,
+        gtk_table_attach (GTK_TABLE (appGUI->cal->aux_calendars_table), appGUI->cal->calendar_next, 1, 2, 1, 2,
                           (GtkAttachOptions) (GTK_FILL),
                           (GtkAttachOptions) (GTK_FILL), 0, 0);
         gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->calendar_next), 
@@ -1822,7 +1860,11 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
 
         appGUI->cal->notes_vbox = gtk_vbox_new (FALSE, 0);
         gtk_widget_show (appGUI->cal->notes_vbox);
-        gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->notes_vbox, TRUE, TRUE, 0);
+		if (!config.gui_layout) {
+	        gtk_box_pack_start (GTK_BOX (vbox3), appGUI->cal->notes_vbox, TRUE, TRUE, 0);
+		} else {
+	        gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->notes_vbox, TRUE, TRUE, 0);
+		}
 
         hbox3 = gtk_hbox_new (FALSE, 0);
         gtk_widget_show (hbox3);
@@ -1982,7 +2024,11 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
 
         appGUI->cal->day_info_vbox = gtk_vbox_new (FALSE, 0);
         gtk_widget_show (appGUI->cal->day_info_vbox);
-        gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->day_info_vbox, TRUE, TRUE, 0);
+		if (!config.gui_layout) {
+	        gtk_box_pack_start (GTK_BOX (vbox3), appGUI->cal->day_info_vbox, TRUE, TRUE, 0);
+		} else {
+	        gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->day_info_vbox, TRUE, TRUE, 0);
+		}
 
         frame = gtk_frame_new (NULL);
         gtk_widget_show (frame);
@@ -2056,9 +2102,13 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
     }
 
     if (appGUI->calendar_only == FALSE) {
-        g_signal_connect (G_OBJECT(appGUI->cal->aux_cal_expander), "notify::expanded", 
-                          G_CALLBACK(aux_cal_expander_cb), appGUI);
-        gtk_expander_set_expanded (GTK_EXPANDER(appGUI->cal->aux_cal_expander), config.auxilary_calendars_state);
+		if (!config.gui_layout) {
+			g_signal_connect (G_OBJECT(appGUI->cal->aux_cal_expander), "notify::expanded", 
+							  G_CALLBACK(aux_cal_expander_cb), appGUI);
+			gtk_expander_set_expanded (GTK_EXPANDER(appGUI->cal->aux_cal_expander), config.auxilary_calendars_state);
+		} else {
+			update_aux_calendars (appGUI);
+		}
     }
 
 }
@@ -2364,7 +2414,7 @@ gboolean flag = FALSE;
 		return;
 
 #ifdef TASKS_ENABLED
-	if (check_tasks (julian_day, TRUE, appGUI) == TRUE) {
+	if (tsk_check_tasks (julian_day, julian_day, STATE_CALENDAR, appGUI) == TRUE) {
 		gui_calendar_mark_day (GUI_CALENDAR (calendar), i, EVENT_MARK);
 		flag = TRUE;
 	}
