@@ -358,7 +358,7 @@ gint current_time, warning_time;
 		utl_subtract_from_date (item->due_date_julian, item->due_time,
 		                        item->warning_days, item->warning_time * 60, &warning_date, &warning_time);
 
-		if (warning_date < current_date + (warning_time < current_time) ? 1 : 0) {
+		if (warning_date < current_date + (warning_time <= current_time) ? 1 : 0) {
 
 			if (item->repeat == TRUE && item->offline_ignore == TRUE) {
 				if (warning_date < appGUI->run_date + (warning_time < appGUI->run_time) ? 1 : 0) {
@@ -578,43 +578,6 @@ gboolean sound_flag = TRUE;
 	return TRUE;
 }
 
-/*------------------------------------------------------------------------------*/
-
-gboolean
-check_tasks (guint32 julian_day, gboolean calendar, GUI *appGUI) {
-
-GtkTreePath *path;
-GtkTreeIter iter;
-gchar *category;
-guint32 date;
-
-    if (appGUI->tsk->tasks_list_store != NULL) {
-        path = gtk_tree_path_new_first();
-
-        while (gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path) == TRUE) {
-            gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
-                                TA_COLUMN_DUE_DATE_JULIAN, &date, TA_COLUMN_CATEGORY, &category, -1);
-
-            if (calendar == TRUE) {
-                if (date == julian_day && tsk_get_category_state (category, STATE_CALENDAR, appGUI) == TRUE) {
-                    return TRUE;
-                }
-            } else if (date == julian_day) {
-                return TRUE;
-            }
-
-            g_free (category);
-            gtk_tree_path_next (path);
-        }
-        gtk_tree_path_free (path);
-
-    }
-
-    return FALSE;
-}
-
-/*------------------------------------------------------------------------------*/
-
 #endif  /* TASKS_ENABLED */
 
 /*------------------------------------------------------------------------------*/
@@ -674,7 +637,7 @@ check_tasks_contacts (guint32 julian_day, GUI *appGUI) {
 
 #ifdef TASKS_ENABLED
     /* check tasks */
-    return check_tasks (julian_day, TRUE, appGUI);
+    return tsk_check_tasks (julian_day, julian_day, STATE_CALENDAR, appGUI);
 #else
     return FALSE;
 #endif  /* TASKS_ENABLED */
