@@ -358,11 +358,7 @@ gboolean flag, leap;
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	if (config.default_stock_icons) {
-		close_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
-	} else {
-		close_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CLOSE);
-	}
+	close_button = utl_gui_create_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
 	gtk_widget_show (close_button);
 	g_signal_connect (close_button, "clicked", G_CALLBACK (button_birthdays_window_close_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), close_button);
