@@ -357,12 +357,7 @@ gchar tmpbuf[BUFFER_SIZE];
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->input_file_entry, GTK_CAN_FOCUS);
     gtk_editable_set_editable (GTK_EDITABLE(appGUI->cnt->input_file_entry), FALSE);
 
-    if (config.default_stock_icons) {
-        appGUI->cnt->contacts_browse_button = utl_gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
-    } else {
-        appGUI->cnt->contacts_browse_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OPEN);
-    }
-
+	appGUI->cnt->contacts_browse_button = utl_gui_create_button (GTK_STOCK_OPEN, OSMO_STOCK_BUTTON_OPEN, _("Browse"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->contacts_browse_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->cnt->contacts_browse_button);
     gtk_box_pack_start (GTK_BOX (hbox4), appGUI->cnt->contacts_browse_button, FALSE, TRUE, 4);
@@ -491,17 +486,13 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
-    if (config.default_stock_icons) {
-        cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-    } else {
-        cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
-    }
+	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
     g_signal_connect(cancel_button, "clicked", 
                      G_CALLBACK(button_import_sel_window_close_cb), appGUI);
 
-    appGUI->cnt->import_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CONTACTS_IMPORT);
+	appGUI->cnt->import_button = utl_gui_create_button (OSMO_STOCK_BUTTON_CONTACTS_IMPORT, OSMO_STOCK_BUTTON_CONTACTS_IMPORT, _("Import"));
     gtk_widget_show (appGUI->cnt->import_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->cnt->import_button);
     g_signal_connect(appGUI->cnt->import_button, "clicked",
