@@ -44,6 +44,10 @@
 
 #include <config.h>
 
+#ifdef CONTACTS_ENABLED
+#include <libgtkhtml/view/htmlview.h>
+#endif  /* CONTACTS_ENABLED */
+
 #ifdef HAVE_LIBNOTIFY
 #ifdef TASKS_ENABLED
 #include <libnotify/notify.h>
@@ -78,8 +82,6 @@ enum notebook_page {
 #ifdef NOTES_ENABLED
     PAGE_NOTES,
 #endif  /* NOTES_ENABLED */
-    PAGE_OPTIONS,
-    PAGE_ABOUT,
     NUMBER_OF_TABS
 };
 
@@ -147,7 +149,7 @@ enum {                  /* contacts columns */
     CONTACTS_NUM_COLUMNS
 };
 
-#define MAX_VISIBLE_NOTE_COLUMNS    4
+#define MAX_VISIBLE_NOTE_COLUMNS    5
 
 enum {                  /* notes columns */
     N_COLUMN_TYPE = 0,          /* V */
@@ -156,12 +158,14 @@ enum {                  /* notes columns */
     N_COLUMN_LAST_CHANGES_DATE, /* V */
     N_COLUMN_LAST_CHANGES_DATE_JULIAN,
     N_COLUMN_LAST_CHANGES_TIME,
-    N_COLUMN_CREATE_DATE,
+    N_COLUMN_CREATE_DATE,       /* V */
     N_COLUMN_CREATE_DATE_JULIAN,
     N_COLUMN_CREATE_TIME,
     N_COLUMN_REMEMBER_EDITOR_LINE,
     N_COLUMN_EDITOR_LINE,
+    N_COLUMN_EDITOR_READONLY,
     N_COLUMN_FILENAME,
+    N_COLUMN_FONTNAME,
     NOTES_NUM_COLUMNS
 };
 
@@ -238,6 +242,7 @@ typedef struct {
 
     /* auxilary calendars */
     GtkWidget *aux_cal_expander;
+	GtkWidget *aux_calendars_table;
     GtkWidget *calendars_table;
     GtkWidget *prev_month_label;
     GtkWidget *next_month_label;
@@ -386,6 +391,9 @@ typedef struct {
     /* number of items label */
     GtkWidget *n_items_label;
 
+	GtkWidget *tasks_find_entry;
+	GtkWidget *tasks_find_clear_button;
+
     GtkWidget *desc_textview;
     GtkWidget *tasks_desc_textview;
     GtkWidget *tasks_list;
@@ -465,6 +473,7 @@ typedef struct {
     GtkWidget *delete_contact_button;
 
     GtkWidget *contacts_find_entry;
+	GtkWidget *contacts_find_clear_button;
     GtkWidget *contacts_find_combobox;
 
     GtkWidget *contacts_paned;
@@ -478,18 +487,7 @@ typedef struct {
     GtkTreeModel *contacts_sort;
 
     GtkWidget *contacts_panel_scrolledwindow;
-    GtkWidget *contacts_desc_textview;
-    GtkWidget *contacts_www_textview;
-    GtkWidget *contacts_email_textview;
-    GtkWidget *contacts_blog_textview;
-    GtkWidget *photo_image;
-    GtkTextTag *contact_name_tag_object;
-    GtkTextTag *contact_tags_value_tag_object;
     GtkUIManager *contacts_uim_widget;
-    GSList contacts_links_list;
-    GSList contacts_www_links_list;
-    GSList contacts_email_links_list;
-    GSList contacts_blog_links_list;
     gint contacts_link_index;
     gint contacts_www_link_index;
     gint contacts_email_link_index;
@@ -549,6 +547,9 @@ typedef struct {
 
     PangoFontDescription *fd_ai_font;
 
+	GtkWidget *html_view;
+	HtmlDocument *html_document;
+
     GtkWidget *input_file_entry;
     GtkWidget *import_type_combobox;
     GtkWidget *bluetooth_radiobutton;
@@ -587,7 +588,10 @@ typedef struct {
     GtkListStore *notes_list_store;
     GtkTreeSelection *notes_list_selection;
 
-    GtkWidget *add_entry_window;
+    GtkWidget *notes_find_entry;
+	GtkWidget *notes_find_clear_button;
+
+	GtkWidget *add_entry_window;
     GtkWidget *edit_entry_window;
     GtkWidget *enter_password_window;
     GtkWidget *add_entry_ok_button;
@@ -619,37 +623,28 @@ typedef struct {
     PangoFontDescription *fd_notes_font;
 
     GtkWidget *title_label;
+    GtkWidget *font_picker;
     GtkWidget *editor_textview;
     GtkWidget *editor_scrolledwindow;
     gboolean changed;
     gboolean find_next_flag;
     gboolean buffer_check_modify_enable;
     gboolean find_hbox_visible;
+	gboolean note_read_only;
+    GtkWidget *nrow_label_t;
+    GtkWidget *nrow_label;
+    GtkWidget *ncol_label_t;
+    GtkWidget *ncol_label;
     GtkWidget *find_hbox;
     GtkWidget *find_entry;
     GtkWidget *find_case_checkbutton;
+    GtkWidget *readonly_checkbutton;
 
 } NOTES;
 #endif  /* NOTES_ENABLED */
 
 typedef struct {
 
-    GtkWidget *calendar_options_radiobutton;
-#ifdef TASKS_ENABLED
-    GtkWidget *tasks_options_radiobutton;
-#endif  /* TASKS_ENABLED */
-#ifdef CONTACTS_ENABLED
-    GtkWidget *contacts_options_radiobutton;
-#endif  /* CONTACTS_ENABLED */
-#ifdef NOTES_ENABLED
-    GtkWidget *notes_options_radiobutton;
-#endif  /* NOTES_ENABLED */
-    GtkWidget *general_options_radiobutton;
-
-    gboolean callback_active;
-    gint options_counter;
-    GtkBox *vbox;
-
     /* calendar */
     GtkWidget *calendar_vbox;
     GtkWidget *event_marker_type_combobox;
@@ -672,6 +667,7 @@ typedef struct {
     GtkWidget *ascending_sorting_in_day_notes_checkbutton;
     GtkWidget *spell_checker_in_day_notes_checkbutton;
     GtkWidget *enable_block_cursor_checkbutton;
+    GtkWidget *date_header_format_entry;
     GtkWidget *day_marker_entry;
     GtkWidget *day_name_font_entry;
     GtkWidget *calendar_font_entry;
@@ -691,6 +687,7 @@ typedef struct {
     GtkWidget *ical_edit_window;
     GtkWidget *ical_edit_name_entry;
     GtkWidget *ical_edit_filename_entry;
+    GtkWidget *ical_edit_disable_checkbutton;
     GtkWidget *ical_edit_filename_browse_button;
     GtkWidget *ical_edit_ok_button;
     GtkWidget *calendar_ical_files_add_button;
@@ -751,8 +748,8 @@ typedef struct {
     GtkWidget *contacts_group_entry;
     GtkListStore *contacts_group_store;
     GtkWidget *contacts_group_treeview;
-    GtkWidget *cn_font_entry;
-    GtkWidget *ci_font_entry;
+    GtkWidget *cn_font_size_spinbutton;
+    GtkWidget *ci_font_size_spinbutton;
     GtkTreeSelection *contacts_group_select;
     GtkWidget *contacts_group_add_button;
     GtkWidget *contacts_group_remove_button;
@@ -785,12 +782,14 @@ typedef struct {
     GtkWidget *nvc_type_checkbutton;
     GtkWidget *nvc_category_checkbutton;
     GtkWidget *nvc_last_changes_checkbutton;
+    GtkWidget *nvc_created_checkbutton;
     GtkWidget *cn_remember_category_checkbutton;
     GtkWidget *cn_use_system_date_checkbutton;
 #endif  /* NOTES_ENABLED */
 
     /* general */
     GtkWidget *general_vbox;
+    GtkWidget *layout_combobox;
     GtkWidget *tabs_position_combobox;
     GtkWidget *override_locale_label_1;
     GtkWidget *override_locale_label_2;
@@ -817,6 +816,15 @@ typedef struct {
     GtkWidget *hide_contacts_checkbutton;
     GtkWidget *hide_notes_checkbutton;
 
+	/* preferences */
+	GtkWidget *window;
+	GtkWidget *notebook;
+	GtkWidget *general;
+	GtkWidget *calendar;
+	GtkWidget *tasks;
+	GtkWidget *notes;
+	GtkWidget *contacts;
+
 } OPTIONS;
 
 
@@ -878,7 +886,7 @@ typedef struct {
     GtkBox *about_vbox;
     gint about_counter;
     gint about_link_index;
-    GSList about_links_list;
+    GSList *about_links_list;
     GtkTextIter about_entry_iter;
     GtkTextBuffer *about_entry_buffer;
 
@@ -918,15 +926,12 @@ typedef struct {
 
 gboolean    gui_create_window               (GUI *appGUI);
 void        gui_add_to_notebook             (GtkWidget *widget, gchar *text, GUI *appGUI);
-void        gui_create_about                (GUI *appGUI);
 void        gui_save_all_data               (GUI *appGUI);
 void        gui_save_data_and_run_command   (gchar *command, GUI *appGUI);
 void        gui_quit_osmo                   (GUI *appGUI);
 void        gui_systray_initialize          (GUI *appGUI);
 void        gui_systray_update_icon         (GUI *appGUI);
 void        gui_systray_tooltip_update      (GUI *appGUI);
-void        about_switch_buttons            (gboolean left, GUI *appGUI);
-void        about_set_first_page            (GUI *appGUI);
 
 #endif /* _GUI_H */
 
