@@ -24,6 +24,7 @@
 #include "calendar_utils.h"
 #include "utils.h"
 #include "utils_date.h"
+#include "utils_gui.h"
 #include "i18n.h"
 #include "check_events.h"
 #include "options_prefs.h"
@@ -140,6 +141,7 @@ GOptionEntry cmd_options[] = {
 
 	appGUI->cal->last_selected_year = -1;
 	appGUI->cal->date = utl_date_new_current ();
+	appGUI->about_links_list = NULL;
 
 #ifdef TASKS_ENABLED
     appGUI->tsk->next_id = 1;
@@ -150,7 +152,6 @@ GOptionEntry cmd_options[] = {
 #endif  /* TASKS_ENABLED */
 
 #ifdef CONTACTS_ENABLED
-    appGUI->cnt->photo_image = NULL;
     appGUI->cnt->contacts_uim_widget = NULL;
     appGUI->cnt->contacts_panel_status = FALSE;
     appGUI->cnt->contacts_filter_disabled = TRUE;
@@ -159,8 +160,6 @@ GOptionEntry cmd_options[] = {
 	appGUI->cnt->write_flag = TRUE;
 #endif  /* CONTACTS_ENABLED */
 
-    appGUI->opt->options_counter = 0;
-
     setlocale (LC_ALL, "");
     bindtextdomain (PACKAGE, LOCALEDIR);
     bind_textdomain_codeset (PACKAGE, "UTF-8");
@@ -220,7 +219,7 @@ GOptionEntry cmd_options[] = {
 							_("Do you really want to continue?"));
 
 				info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW_TOPLEVEL, GTK_DIALOG_MODAL,
-													  GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, tmpbuf);
+													  GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, tmpbuf, NULL);
 
 				gtk_window_set_title(GTK_WINDOW(info_dialog), _("Warning"));
 				gtk_window_set_position(GTK_WINDOW(info_dialog), GTK_WIN_POS_CENTER);
@@ -280,6 +279,9 @@ GOptionEntry cmd_options[] = {
 
 finish:
 	g_date_free (appGUI->cal->date);
+	utl_gui_url_remove_links (&appGUI->about_links_list, NULL);
+	gdk_cursor_unref (appGUI->hand_cursor);
+	gdk_cursor_unref (appGUI->regular_cursor);
 	g_free (opt);
 
 #ifdef NOTES_ENABLED
