@@ -33,9 +33,11 @@
 void        notes_show_selector_editor  (gint mode, GUI *appGUI);
 void        gui_create_notes            (GUI *appGUI);
 void        update_notes_items          (GUI *appGUI);
+void        refresh_notes               (GUI *appGUI);
 gboolean    check_if_encrypted          (gchar *filename, GUI *appGUI);
 void        check_notes_type            (GUI *appGUI);
 void        store_note_columns_info     (GUI *appGUI);
+void        set_note_columns_width      (GUI *appGUI);
 
 #endif /* _NOTES_H */
 
