@@ -88,8 +88,8 @@ prefs_set_default_values (void) {
 gint i;
 
     /* general */
-    config.window_x = 180;
-    config.window_y = 80;
+    config.window_x = 0;
+    config.window_y = 0;
     config.window_size_x = 540;
     config.window_size_y = 690;
     config.enable_tooltips = TRUE;
@@ -114,7 +114,9 @@ gint i;
     config.hide_contacts = FALSE;
     config.hide_notes = FALSE;
     config.override_locale_settings = FALSE;
+    config.gui_layout = 0;      /* 0 - vertical, 1 - horizontal */
     config.sound_alarm_repeat = 1;
+	g_strlcpy (config.link_color, "blue", MAXCOLORNAME);
     g_strlcpy (config.spell_lang, g_getenv("LANG"), MAXNAME);
 	g_strlcpy (config.web_browser, "xdg-open %s", MAXHELPERCMD);
 	g_strlcpy (config.email_client, "xdg-email %s", MAXHELPERCMD);
@@ -153,6 +155,7 @@ gint i;
     config.auxilary_calendars_state = FALSE;
     config.day_note_spell_checker = FALSE;
     g_strlcpy (config.day_note_marker, "\'", MAXNAME);
+    g_strlcpy (config.date_header_format, DEFAULT_DATE_HEADER_FORMAT, MAXNAME);
     config.event_marker_type = EVENT_MARKER_CIRCLE;
     config.today_marker_type = TODAY_MARKER_FREEHAND_CIRCLE;
     config.day_notes_browser_filter = DN_FILTER_CURRENT_MONTH;
@@ -256,11 +259,11 @@ gint i;
     config.import_bluetooth_channel = 1;
     config.import_usb_interface = 0;
     config.import_binary_xml = 0;
+	config.contact_name_font_size = 18;
+	config.contact_item_font_size = 11;
 	g_strlcpy (config.import_bluetooth_address, "00:00:00:00:00:00", MAXADDRESS);
 	g_strlcpy (config.contact_tag_color, "#228B22", MAXCOLORNAME);
 	g_strlcpy (config.contact_link_color, "blue", MAXCOLORNAME);
-	g_strlcpy (config.contact_name_font, "Sans 18", MAXFONTNAME);
-	g_strlcpy (config.contact_item_font, "Sans 11", MAXFONTNAME);
 
     config.export_format = EXPORT_TO_CSV;
 
@@ -283,6 +286,7 @@ gint i;
     config.nte_visible_type_column = TRUE;
     config.nte_visible_category_column = TRUE;
     config.nte_visible_last_changes_column = TRUE;
+    config.nte_visible_created_column = TRUE;
 	config.notes_column_idx_0 = 0;
 	config.notes_column_idx_0_width = 50;
 	config.notes_column_idx_1 = 1;
@@ -291,6 +295,8 @@ gint i;
 	config.notes_column_idx_2_width = 80;
 	config.notes_column_idx_3 = 3;
 	config.notes_column_idx_3_width = 150;
+	config.notes_column_idx_4 = 4;
+	config.notes_column_idx_4_width = 150;
     config.remember_category_in_notes = FALSE;
     config.current_category_in_notes = 0;
     config.use_system_date_in_notes = FALSE;
@@ -362,6 +368,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("hide_contacts", &config.hide_contacts, general_node);
 					utl_xml_get_int ("hide_notes", &config.hide_notes, general_node);
 					utl_xml_get_int ("override_locale_settings", &config.override_locale_settings, general_node);
+					utl_xml_get_int ("gui_layout", &config.gui_layout, general_node);
 					utl_xml_get_int ("sound_alarm_repeat", &config.sound_alarm_repeat, general_node);
 					utl_xml_get_strn ("spell_lang", config.spell_lang, MAXNAME, general_node);
 					utl_xml_get_strn ("web_browser", config.web_browser, MAXHELPERCMD, general_node);
@@ -412,6 +419,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("auxilary_calendars_state", &config.auxilary_calendars_state, calendar_node);
 					utl_xml_get_int ("day_note_spell_checker", &config.day_note_spell_checker, calendar_node);
 					utl_xml_get_strn ("day_note_marker", config.day_note_marker, MAXNAME, calendar_node);
+					utl_xml_get_strn ("date_header_format", config.date_header_format, MAXNAME, calendar_node);
 					utl_xml_get_int ("event_marker_type", &config.event_marker_type, calendar_node);
 					utl_xml_get_int ("today_marker_type", &config.today_marker_type, calendar_node);
 					utl_xml_get_int ("day_notes_browser_filter", &config.day_notes_browser_filter, calendar_node);
@@ -508,8 +516,8 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("visible_zodiac_sign_column", &config.cnt_visible_zodiac_sign_column, contacts_node);
 					utl_xml_get_strn ("contact_tag_color", config.contact_tag_color, MAXCOLORNAME, contacts_node);
 					utl_xml_get_strn ("contact_link_color", config.contact_link_color, MAXCOLORNAME, contacts_node);
-					utl_xml_get_strn ("contact_name_font", config.contact_name_font, MAXFONTNAME, contacts_node);
-					utl_xml_get_strn ("contact_item_font", config.contact_item_font, MAXFONTNAME, contacts_node);
+					utl_xml_get_int ("contact_name_font_size", &config.contact_name_font_size, contacts_node);
+					utl_xml_get_int ("contact_item_font_size", &config.contact_item_font_size, contacts_node);
 					utl_xml_get_int ("export_format", &config.export_format, contacts_node);
 					utl_xml_get_strn ("export_fields", config.export_fields, MAXCONTACTFIELDS, contacts_node);
 					utl_xml_get_int ("contacts_sorting_order", &config.contacts_sorting_order, contacts_node);
@@ -563,6 +571,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("visible_type_column", &config.nte_visible_type_column, notes_node);
 					utl_xml_get_int ("visible_category_column", &config.nte_visible_category_column, notes_node);
 					utl_xml_get_int ("visible_last_changes_column", &config.nte_visible_last_changes_column, notes_node);
+					utl_xml_get_int ("visible_created_column", &config.nte_visible_created_column, notes_node);
 					utl_xml_get_int ("column_idx_0", &config.notes_column_idx_0, notes_node);
 					utl_xml_get_int ("column_idx_0_width", &config.notes_column_idx_0_width, notes_node);
 					utl_xml_get_int ("column_idx_1", &config.notes_column_idx_1, notes_node);
@@ -571,6 +580,8 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("column_idx_2_width", &config.notes_column_idx_2_width, notes_node);
 					utl_xml_get_int ("column_idx_3", &config.notes_column_idx_3, notes_node);
 					utl_xml_get_int ("column_idx_3_width", &config.notes_column_idx_3_width, notes_node);
+					utl_xml_get_int ("column_idx_4", &config.notes_column_idx_4, notes_node);
+					utl_xml_get_int ("column_idx_4_width", &config.notes_column_idx_4_width, notes_node);
 					utl_xml_get_int ("remember_category", &config.remember_category_in_notes, notes_node);
 					utl_xml_get_int ("current_category", &config.current_category_in_notes, notes_node);
 					utl_xml_get_int ("use_system_date", &config.use_system_date_in_notes, notes_node);
@@ -643,6 +654,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("hide_contacts", config.hide_contacts, general_node);
 	utl_xml_put_int ("hide_notes", config.hide_notes, general_node);
 	utl_xml_put_int ("override_locale_settings", config.override_locale_settings, general_node);
+	utl_xml_put_int ("gui_layout", config.gui_layout, general_node);
 	utl_xml_put_int ("sound_alarm_repeat", config.sound_alarm_repeat, general_node);
 	utl_xml_put_strn ("spell_lang", config.spell_lang, MAXNAME, general_node, doc);
 	utl_xml_put_strn ("web_browser", config.web_browser, MAXHELPERCMD, general_node, doc);
@@ -687,6 +699,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("auxilary_calendars_state", config.auxilary_calendars_state, calendar_node);
 	utl_xml_put_int ("day_note_spell_checker", config.day_note_spell_checker, calendar_node);
 	utl_xml_put_strn ("day_note_marker", config.day_note_marker, MAXNAME, calendar_node, doc);
+	utl_xml_put_strn ("date_header_format", config.date_header_format, MAXNAME, calendar_node, doc);
 	utl_xml_put_int ("event_marker_type", config.event_marker_type, calendar_node);
 	utl_xml_put_int ("today_marker_type", config.today_marker_type, calendar_node);
 	utl_xml_put_int ("day_notes_browser_filter", config.day_notes_browser_filter, calendar_node);
@@ -773,8 +786,8 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("visible_zodiac_sign_column", config.cnt_visible_zodiac_sign_column, contacts_node);
 	utl_xml_put_strn ("contact_tag_color", config.contact_tag_color, MAXCOLORNAME, contacts_node, doc);
 	utl_xml_put_strn ("contact_link_color", config.contact_link_color, MAXCOLORNAME, contacts_node, doc);
-	utl_xml_put_strn ("contact_name_font", config.contact_name_font, MAXFONTNAME, contacts_node, doc);
-	utl_xml_put_strn ("contact_item_font", config.contact_item_font, MAXFONTNAME, contacts_node, doc);
+	utl_xml_put_int ("contact_name_font_size", config.contact_name_font_size, contacts_node);
+	utl_xml_put_int ("contact_item_font_size", config.contact_item_font_size, contacts_node);
 	utl_xml_put_int ("export_format", config.export_format, contacts_node);
 	utl_xml_put_strn ("export_fields", config.export_fields, MAXCONTACTFIELDS, contacts_node, doc);
 	utl_xml_put_int ("contacts_sorting_order", config.contacts_sorting_order, contacts_node);
@@ -823,6 +836,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("visible_type_column", config.nte_visible_type_column, notes_node);
 	utl_xml_put_int ("visible_category_column", config.nte_visible_category_column, notes_node);
 	utl_xml_put_int ("visible_last_changes_column", config.nte_visible_last_changes_column, notes_node);
+	utl_xml_put_int ("visible_created_column", config.nte_visible_created_column, notes_node);
 	utl_xml_put_int ("column_idx_0", config.notes_column_idx_0, notes_node);
 	utl_xml_put_int ("column_idx_0_width", config.notes_column_idx_0_width, notes_node);
 	utl_xml_put_int ("column_idx_1", config.notes_column_idx_1, notes_node);
@@ -831,6 +845,8 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("column_idx_2_width", config.notes_column_idx_2_width, notes_node);
 	utl_xml_put_int ("column_idx_3", config.notes_column_idx_3, notes_node);
 	utl_xml_put_int ("column_idx_3_width", config.notes_column_idx_3_width, notes_node);
+	utl_xml_put_int ("column_idx_4", config.notes_column_idx_4, notes_node);
+	utl_xml_put_int ("column_idx_4_width", config.notes_column_idx_4_width, notes_node);
 	utl_xml_put_int ("remember_category", config.remember_category_in_notes, notes_node);
 	utl_xml_put_int ("current_category", config.current_category_in_notes, notes_node);
 	utl_xml_put_int ("use_system_date", config.use_system_date_in_notes, notes_node);
