@@ -19,12 +19,14 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "about.h"
 #include "calendar.h"
 #include "calendar_utils.h"
 #include "calendar_widget.h"
 #include "i18n.h"
-#include "options_gui_tasks.h"
+#include "tasks_preferences_gui.h"
 #include "options_prefs.h"
+#include "preferences_gui.h"
 #include "stock_icons.h"
 #include "tasks.h"
 #include "tasks_items.h"
@@ -38,6 +40,27 @@
 
 /*============================================================================*/
 
+static void
+show_about_window_cb (GtkWidget *widget, GUI *appGUI)
+{
+	GtkWidget *window = opt_create_about_window (appGUI);
+	gtk_widget_show (window);
+}
+
+/*============================================================================*/
+
+static void
+show_preferences_window_cb (GtkWidget *widget, GUI *appGUI)
+{
+	appGUI->opt->window = opt_create_preferences_window (appGUI);
+	gtk_widget_show (appGUI->opt->window);
+
+	gint page = gtk_notebook_page_num (GTK_NOTEBOOK (appGUI->opt->notebook), appGUI->opt->tasks);
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->opt->notebook), page);
+}
+
+/*============================================================================*/
+
 gint
 task_calculate_new_date (TASK_ITEM *item, GUI *appGUI, guint32 *new_date, gint *new_time)
 {
@@ -203,7 +226,9 @@ GtkTreeModel *model;
     } else {
 
         config.tasks_pane_pos = gtk_paned_get_position(GTK_PANED(appGUI->tsk->tasks_paned));
-        gtk_paned_set_position(GTK_PANED(appGUI->tsk->tasks_paned), 99999);
+		if (!config.gui_layout) {
+	        gtk_paned_set_position(GTK_PANED(appGUI->tsk->tasks_paned), 99999);
+		}
 
     }
 
@@ -289,7 +314,11 @@ gboolean repeat, prev_state, next_state;
 
             hseparator = gtk_hseparator_new ();
             gtk_widget_show (hseparator);
-            gtk_widget_set_size_request (hseparator, 320, -1);
+			if (!config.gui_layout) {
+                gtk_widget_set_size_request (hseparator, 320, -1);
+			} else {
+                gtk_widget_set_size_request (hseparator, 200, -1);
+			}
             gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW(appGUI->tsk->tasks_desc_textview), hseparator, anchor);
         }
 
@@ -753,16 +782,29 @@ tasks_list_filter_cb (GtkTreeModel *model, GtkTreeIter *iter, gpointer data) {
 
 gint done, idx;
 gchar *category, *category_cf;
+const gchar *text;
+gchar *value;
+gint text_len, len, j;
 
     GUI *appGUI = (GUI *)data;
 
+	text = gtk_entry_get_text (GTK_ENTRY(appGUI->tsk->tasks_find_entry));
+
+    if (text == NULL) {
+        return TRUE;
+    }
+
+    text_len = strlen (text);
+
     if (appGUI->tsk->tasks_filter_disabled == TRUE)
         return TRUE;
 
-    gtk_tree_model_get(model, iter, TA_COLUMN_DONE, &done, TA_COLUMN_CATEGORY, &category, -1);
+    gtk_tree_model_get (model, iter, TA_COLUMN_DONE, &done, 
+					    TA_COLUMN_CATEGORY, &category, TA_COLUMN_SUMMARY, &value, -1);
     
     if (tsk_get_category_state (category, STATE_TASKS, appGUI) == FALSE) {
         g_free (category);
+        g_free (value);
         return FALSE;
     }
 
@@ -770,29 +812,70 @@ gchar *category, *category_cf;
     idx = utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category_cf);
     g_free (category_cf);
 
-    if(idx) {
+    if (idx) {
 
         if (utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category) == idx) {
 
             if(config.hide_completed && done == TRUE) {
                 g_free (category);
+                g_free (value);
                 return FALSE;
             }
+
+			if (value != NULL) {
+
+				len = strlen(value) - text_len;
+
+				if (len >= 0) {
+					for(j=0; j <= len; j++) {
+						if(!g_ascii_strncasecmp(g_utf8_casefold(text, -1), g_utf8_casefold(value+j, -1), text_len)) {
+							g_free (value);
+							g_free (category);
+							return TRUE;
+						}
+					}
+				}
+
+				g_free(value);
+			}
+
             g_free (category);
-            return TRUE;
+            return FALSE;
 
         } else {
             g_free (category);
+            g_free (value);
             return FALSE;
         }
 
-    } else if (config.hide_completed && done == TRUE) {
+    } else {
+
+		if (config.hide_completed && done == TRUE) {
             g_free (category);
+            g_free (value);
             return FALSE;
+		}
+
+		if (value != NULL) {
+
+			len = strlen(value) - text_len;
+
+			if (len >= 0) {
+				for(j=0; j <= len; j++) {
+					if(!g_ascii_strncasecmp(g_utf8_casefold(text, -1), g_utf8_casefold(value+j, -1), text_len)) {
+						g_free (value);
+						g_free (category);
+						return TRUE;
+					}
+				}
+			}
+
+			g_free(value);
+		}
     }
 
     g_free (category);
-    return TRUE;
+    return FALSE;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1038,31 +1121,78 @@ void
 set_tasks_columns_width (GUI *appGUI) {
 
 GtkTreeViewColumn   *col;
+gint w;
+
+	w = 2 * utl_gui_get_sw_vscrollbar_width (appGUI->tsk->scrolled_win);
 
 	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 0);
-	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+	if (gtk_tree_view_column_get_visible(col) == TRUE && config.tasks_column_idx_0_width > 0) {
 		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_0_width);
 	}
 	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 1);
-	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+	if (gtk_tree_view_column_get_visible(col) == TRUE && config.tasks_column_idx_1_width > 0) {
 		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_1_width);
 	}
 	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 2);
-	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+	if (gtk_tree_view_column_get_visible(col) == TRUE && config.tasks_column_idx_2_width > 0) {
 		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_2_width);
 	}
 	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 3);
-	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+	if (gtk_tree_view_column_get_visible(col) == TRUE && config.tasks_column_idx_3_width > 0) {
 		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_3_width);
 	}
 	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 4);
-	if (gtk_tree_view_column_get_visible(col) == TRUE) {
+	if (gtk_tree_view_column_get_visible(col) == TRUE && config.tasks_column_idx_4_width > 0) {
 		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_4_width);
 	}
 	col = gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 5);
-	if (gtk_tree_view_column_get_visible(col) == TRUE) {
-		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_5_width - 
-											  2 * utl_gui_get_sw_vscrollbar_width (appGUI->tsk->scrolled_win));
+	if (gtk_tree_view_column_get_visible(col) == TRUE && config.tasks_column_idx_5_width > w) {
+		gtk_tree_view_column_set_fixed_width (col, config.tasks_column_idx_5_width - w);
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
+gboolean
+tasks_search_entry_changed_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data) {
+
+GtkTreePath *path;
+GtkTreeIter iter;
+gint i;
+
+    GUI *appGUI = (GUI *)user_data;
+
+    gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter));
+
+    if(strlen(gtk_entry_get_text (GTK_ENTRY(appGUI->tsk->tasks_find_entry)))) {
+
+		i = 0;
+		while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_filter), &iter, NULL, i++));
+
+		if (i-1 != 0) {
+
+			path = gtk_tree_path_new_first();
+			if (path != NULL) {
+				gtk_tree_view_set_cursor (GTK_TREE_VIEW (appGUI->tsk->tasks_list), path, NULL, FALSE);
+				gtk_tree_path_free (path);
+			}
+		} 
+    }
+		
+	update_tasks_number (appGUI);
+
+    return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_clear_find_cb (GtkWidget *widget, gpointer user_data)
+{
+	GUI *appGUI = (GUI *) user_data;
+    if (strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->tsk->tasks_find_entry)))) {
+        gtk_entry_set_text(GTK_ENTRY(appGUI->tsk->tasks_find_entry), "");
+		refresh_tasks (appGUI);
 	}
 }
 
@@ -1073,6 +1203,7 @@ gui_create_tasks(GUI *appGUI) {
 
 GtkWidget           *vbox1;
 GtkWidget           *vbox2;
+GtkWidget           *vbox3;
 GtkWidget           *table;
 GtkWidget           *label;
 GtkWidget           *hseparator;
@@ -1090,12 +1221,12 @@ gint i, n;
 "  <toolbar name=\"toolbar\">\n"
 "    <toolitem name=\"add\" action=\"add\" />\n"
 "    <toolitem name=\"edit\" action=\"edit\" />\n"
-"    <separator name=\"sep1\" />\n"
+"    <separator/>\n"
 "    <toolitem name=\"delete\" action=\"delete\" />\n"
-"    <separator name=\"sep2\" />\n"
+"    <separator/>\n"
 "    <toolitem name=\"prev_date\" action=\"prev_date\" />\n"
 "    <toolitem name=\"next_date\" action=\"next_date\" />\n"
-"    <separator name=\"sep3\" />\n"
+"    <separator/>\n"
 #if 0
 "    <toolitem name=\"import\" action=\"import\" />\n"
 #endif
@@ -1103,26 +1234,31 @@ gint i, n;
 "    <toolitem name=\"export\" action=\"export\" />\n"
 #endif
 #ifdef PRINTING_SUPPORT
-"    <separator name=\"sep4\" />\n"
+"    <separator/>\n"
 "    <toolitem name=\"print\" action=\"print\" />\n"
+"    <separator expand=\"true\" />\n"
+"    <toolitem name=\"preferences\" action=\"preferences\" />\n"
+"    <toolitem name=\"about\" action=\"about\" />\n"
 #endif /* PRINTING_SUPPORT */
 "  </toolbar>\n";
 
 GtkActionEntry entries[] = {
-  { "add", OSMO_STOCK_TASKS_ADD, _("New task"), NULL, _("New task"), NULL },
-  { "edit", OSMO_STOCK_TASKS_EDIT, _("Edit task"), NULL, _("Edit task"), NULL },
-  { "delete", OSMO_STOCK_TASKS_REMOVE, _("Remove task"), NULL, _("Remove task"), NULL },
-  { "prev_date", OSMO_STOCK_TASKS_PREV_DATE, _("Change due date to previous date"), NULL, _("Change due date to previous date"), NULL },
-  { "next_date", OSMO_STOCK_TASKS_NEXT_DATE, _("Change due date to next date"), NULL, _("Change due date to next date"), NULL },
+  { "add", OSMO_STOCK_TASKS_ADD, _("New task"), NULL, _("New task"), G_CALLBACK(tasks_add_item_cb)},
+  { "edit", OSMO_STOCK_TASKS_EDIT, _("Edit task"), NULL, _("Edit task"), G_CALLBACK(tasks_edit_item_cb)},
+  { "delete", OSMO_STOCK_TASKS_REMOVE, _("Remove task"), NULL, _("Remove task"), G_CALLBACK(tasks_remove_item_cb)},
+  { "prev_date", OSMO_STOCK_TASKS_PREV_DATE, _("Change due date to previous date"), NULL, _("Change due date to previous date"), G_CALLBACK(tasks_change_due_date_to_prev_date_cb)},
+  { "next_date", OSMO_STOCK_TASKS_NEXT_DATE, _("Change due date to next date"), NULL, _("Change due date to next date"), G_CALLBACK(tasks_change_due_date_to_next_date_cb)},
 #if 0
   { "import", OSMO_STOCK_TASKS_IMPORT, _("Import tasks"), NULL, _("Import tasks"), NULL },
 #endif
 #ifdef HAVE_LIBICAL
-  { "export", OSMO_STOCK_TASKS_EXPORT, _("Export tasks"), NULL, _("Export tasks"), NULL },
+  { "export", OSMO_STOCK_TASKS_EXPORT, _("Export tasks"), NULL, _("Export tasks"), G_CALLBACK(tasks_export_visible_items_cb)},
 #endif
 #ifdef PRINTING_SUPPORT
-  { "print", OSMO_STOCK_PRINT, _("Print visible tasks list"), NULL, _("Print visible tasks list"), NULL },
+  { "print", OSMO_STOCK_PRINT, _("Print visible tasks list"), NULL, _("Print visible tasks list"), G_CALLBACK(tasks_print_visible_items_cb)},
 #endif /* PRINTING_SUPPORT */
+	{ "preferences", OSMO_STOCK_PREFERENCES, _("Preferences"), NULL, _("Preferences"), G_CALLBACK (show_preferences_window_cb)},
+	{ "about", OSMO_STOCK_ABOUT, _("About"), NULL, _("About"), G_CALLBACK (show_about_window_cb)},
 };
 
 gint columns_order[MAX_VISIBLE_TASK_COLUMNS];
@@ -1151,7 +1287,7 @@ guint n_entries = G_N_ELEMENTS (entries);
     /*-------------------------------------------------------------------------------------*/
 
     action_group = gtk_action_group_new ("_actions");
-    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
+    gtk_action_group_add_actions (action_group, entries, n_entries, appGUI);
     gtk_action_group_set_sensitive(action_group, TRUE);
 
     appGUI->tsk->tasks_uim_widget = gtk_ui_manager_new ();
@@ -1167,28 +1303,6 @@ guint n_entries = G_N_ELEMENTS (entries);
 
     gtk_toolbar_set_style (appGUI->tsk->tasks_toolbar, GTK_TOOLBAR_ICONS);
 
-    /*-------------------------------------------------------------------------------------*/
-    /* assign callbacks */
-
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/add")), "clicked", 
-                      G_CALLBACK(tasks_add_item_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit")), "clicked", 
-                      G_CALLBACK(tasks_edit_item_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete")), "clicked", 
-                      G_CALLBACK(tasks_remove_item_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_date")), "clicked", 
-                      G_CALLBACK(tasks_change_due_date_to_prev_date_cb), appGUI);
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_date")), "clicked", 
-                      G_CALLBACK(tasks_change_due_date_to_next_date_cb), appGUI);
-#ifdef HAVE_LIBICAL
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/export")), "clicked", 
-                      G_CALLBACK(tasks_export_visible_items_cb), appGUI);
-#endif /* HAVE_LIBICAL */
-#ifdef PRINTING_SUPPORT
-    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print")), "clicked", 
-                      G_CALLBACK(tasks_print_visible_items_cb), appGUI);
-#endif /* PRINTING_SUPPORT */
-
     /*-------------------------------------------------------------------------------------*/
 
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit"), FALSE);
@@ -1199,16 +1313,37 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), FALSE);
 #endif /* PRINTING_SUPPORT */
 
+    /*-------------------------------------------------------------------------------------*/
+
+	if (!config.gui_layout) {
+	    appGUI->tsk->tasks_paned = gtk_vpaned_new();
+        gtk_paned_set_position(GTK_PANED(appGUI->tsk->tasks_paned), 99999);
+	} else {
+	    appGUI->tsk->tasks_paned = gtk_hpaned_new();
+	}
+    gtk_widget_show (appGUI->tsk->tasks_paned);
+    gtk_box_pack_start(GTK_BOX(vbox1), appGUI->tsk->tasks_paned, TRUE, TRUE, 0);
+
+    top_viewport = gtk_viewport_new (NULL, NULL);
+    gtk_widget_show (top_viewport);
+    gtk_viewport_set_shadow_type (GTK_VIEWPORT (top_viewport), GTK_SHADOW_NONE);
+    gtk_paned_pack1 (GTK_PANED (appGUI->tsk->tasks_paned), top_viewport, FALSE, TRUE);
+
+    vbox3 = gtk_vbox_new (FALSE, 1);
+    gtk_widget_show (vbox3);
+    gtk_container_add (GTK_CONTAINER (top_viewport), vbox3);
+
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 6);
+    gtk_box_pack_start (GTK_BOX (vbox3), hseparator, FALSE, TRUE, 6);
 
-    table = gtk_table_new (1, 4, FALSE);
+    table = gtk_table_new (2, 4, FALSE);
     gtk_widget_show (table);
-    gtk_box_pack_start (GTK_BOX (vbox1), table, FALSE, TRUE, 0);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+    gtk_box_pack_start (GTK_BOX (vbox3), table, FALSE, TRUE, 0);
+    gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
 
-    sprintf(tmpbuf, "<b>%s:</b>", _("Category filter"));
+    sprintf(tmpbuf, "<b>%s:</b>", _("Category"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
@@ -1244,25 +1379,45 @@ guint n_entries = G_N_ELEMENTS (entries);
                      (GtkAttachOptions) (0), 0, 0);
     gtk_label_set_use_markup (GTK_LABEL (appGUI->tsk->n_items_label), TRUE);
 
+	sprintf(tmpbuf, "<b>%s:</b>", _("Search"));
+	label = gtk_label_new (tmpbuf);
+	gtk_widget_show (label);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+					 (GtkAttachOptions) (GTK_FILL),
+					 (GtkAttachOptions) (0), 0, 0);
+
+	appGUI->tsk->tasks_find_entry = gtk_entry_new();
+	gtk_entry_set_max_length(GTK_ENTRY(appGUI->tsk->tasks_find_entry), 128);
+	gtk_widget_show (appGUI->tsk->tasks_find_entry);
+	g_signal_connect (G_OBJECT(appGUI->tsk->tasks_find_entry), "key_release_event",
+					  G_CALLBACK(tasks_search_entry_changed_cb), appGUI);
+	gtk_table_attach (GTK_TABLE (table), appGUI->tsk->tasks_find_entry, 1, 4, 1, 2,
+					 (GtkAttachOptions) (GTK_FILL),
+					 (GtkAttachOptions) (0), 0, 0);
+
+	appGUI->tsk->tasks_find_clear_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
+	gtk_widget_show (appGUI->tsk->tasks_find_clear_button);
+	GTK_WIDGET_UNSET_FLAGS (appGUI->tsk->tasks_find_clear_button, GTK_CAN_FOCUS);
+	gtk_button_set_relief (GTK_BUTTON(appGUI->tsk->tasks_find_clear_button), GTK_RELIEF_NONE);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->tsk->tasks_find_clear_button, _("Clear"));
+	}
+	g_signal_connect (G_OBJECT (appGUI->tsk->tasks_find_clear_button), "clicked",
+						G_CALLBACK (gui_clear_find_cb), appGUI);
+	gtk_table_attach (GTK_TABLE (table), appGUI->tsk->tasks_find_clear_button, 4, 5, 1, 2,
+					 (GtkAttachOptions) (GTK_FILL),
+					 (GtkAttachOptions) (0), 0, 0);
+
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 6);
+    gtk_box_pack_start (GTK_BOX (vbox3), hseparator, FALSE, TRUE, 6);
 
-    /*-------------------------------------------------------------------------------------*/
-
-    appGUI->tsk->tasks_paned = gtk_vpaned_new();
-    gtk_widget_show (appGUI->tsk->tasks_paned);
-    gtk_paned_set_position(GTK_PANED(appGUI->tsk->tasks_paned), 99999);
-    gtk_box_pack_start(GTK_BOX(vbox1), appGUI->tsk->tasks_paned, TRUE, TRUE, 0);
-
-    top_viewport = gtk_viewport_new (NULL, NULL);
-    gtk_widget_show (top_viewport);
-    gtk_viewport_set_shadow_type (GTK_VIEWPORT (top_viewport), GTK_SHADOW_NONE);
-    gtk_paned_pack1 (GTK_PANED (appGUI->tsk->tasks_paned), top_viewport, FALSE, TRUE);
 
     appGUI->tsk->scrolled_win = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_show (appGUI->tsk->scrolled_win);
-    gtk_container_add (GTK_CONTAINER (top_viewport), appGUI->tsk->scrolled_win);
+    gtk_box_pack_start (GTK_BOX (vbox3), appGUI->tsk->scrolled_win, TRUE, TRUE, 0);
 
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (appGUI->tsk->scrolled_win), GTK_SHADOW_IN);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->tsk->scrolled_win), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -1285,7 +1440,6 @@ guint n_entries = G_N_ELEMENTS (entries);
     appGUI->tsk->tasks_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(appGUI->tsk->tasks_sort));
     gtk_tree_view_set_rules_hint (GTK_TREE_VIEW(appGUI->tsk->tasks_list), config.rules_hint);
     gtk_widget_show (appGUI->tsk->tasks_list);
-    GTK_WIDGET_SET_FLAGS (appGUI->tsk->tasks_list, GTK_CAN_DEFAULT);
     gtk_widget_modify_fg(GTK_WIDGET(appGUI->tsk->tasks_list), GTK_STATE_SELECTED,
                          (& GTK_WIDGET(appGUI->tsk->tasks_list)->style->base[GTK_STATE_SELECTED]));
     gtk_widget_modify_fg(GTK_WIDGET(appGUI->tsk->tasks_list), GTK_STATE_NORMAL,
@@ -1643,19 +1797,21 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (appGUI->tsk->panel_hbox), label, FALSE, FALSE, 0);
 
-    if (config.default_stock_icons) {
-        close_button = utl_gui_stock_button(GTK_STOCK_CLOSE, FALSE);
-    } else {
-        close_button = utl_gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
-    }
-    GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
-    gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
-	if (config.enable_tooltips) {
-		gtk_widget_set_tooltip_text (close_button, _("Close description panel"));
+	if (!config.gui_layout) {
+		if (config.default_stock_icons) {
+			close_button = utl_gui_stock_button(GTK_STOCK_CLOSE, FALSE);
+		} else {
+			close_button = utl_gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
+		}
+		GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
+		gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
+		if (config.enable_tooltips) {
+			gtk_widget_set_tooltip_text (close_button, _("Close description panel"));
+		}
+		gtk_box_pack_end (GTK_BOX (appGUI->tsk->panel_hbox), close_button, FALSE, FALSE, 0);
+		g_signal_connect (G_OBJECT (close_button), "clicked",
+							G_CALLBACK (panel_close_desc_cb), appGUI);
 	}
-    gtk_box_pack_end (GTK_BOX (appGUI->tsk->panel_hbox), close_button, FALSE, FALSE, 0);
-    g_signal_connect (G_OBJECT (close_button), "clicked",
-                        G_CALLBACK (panel_close_desc_cb), appGUI);
 
     appGUI->tsk->panel_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_show (appGUI->tsk->panel_scrolledwindow);
@@ -1679,6 +1835,11 @@ guint n_entries = G_N_ELEMENTS (entries);
     appGUI->tsk->font_tag_object = gtk_text_buffer_create_tag (text_buffer, "info_font",
                       "font", (gchar *) config.task_info_font, NULL);
 
+	if (config.gui_layout) {
+	    gtk_paned_set_position(GTK_PANED(appGUI->tsk->tasks_paned), config.tasks_pane_pos);
+	}
+
+	gtk_widget_grab_focus (appGUI->tsk->tasks_find_entry);
 }
 
 /*------------------------------------------------------------------------------*/
