@@ -39,6 +39,40 @@ utl_text_replace (const gchar *text, const gchar *regex, const gchar *replacemen
 
 /*------------------------------------------------------------------------------*/
 
+gchar *
+utl_text_to_html (const gchar *text, gboolean ignoreBR)
+{
+
+const gchar *pairs[] = {
+	"&",    "&amp;", 
+	"\"",   "&quot;", 
+	"<",    "&lt;", 
+	">",    "&gt;",
+	"\\n",  "<br />"    /* must be the last entry here */
+};
+
+GRegex *reg;
+gint i = 0;
+gchar *buffer = NULL, *temp = NULL;
+guint n_pairs = G_N_ELEMENTS (pairs) / 2;
+
+	temp = g_strdup(text);
+
+	if (ignoreBR) --n_pairs;
+
+	for (i=0; i < n_pairs; i++) {
+		reg = g_regex_new (pairs[i*2+0], 0, 0, NULL);
+		buffer = g_regex_replace_literal (reg, temp, -1, 0, pairs[i*2+1], 0, NULL);
+		g_free (temp);
+		temp = buffer;
+		g_regex_unref (reg);
+	}
+
+	return temp;
+}
+
+/*------------------------------------------------------------------------------*/
+
 gchar *
 utl_get_day_name (guint day, gboolean short_name)
 {
@@ -89,6 +123,17 @@ utl_get_date_name (const GDate *date)
 
 /*------------------------------------------------------------------------------*/
 
+gchar *
+utl_get_date_name_format (const GDate *date, gchar *fmt)
+{
+	static gchar buffer[BUFFER_SIZE];
+
+	g_date_strftime (buffer, BUFFER_SIZE, fmt, date);
+	return buffer;
+}
+
+/*------------------------------------------------------------------------------*/
+
 guint
 utl_get_weekend_days_in_month (const GDate *date)
 {
@@ -475,22 +520,18 @@ gboolean sync = FALSE;
 /*------------------------------------------------------------------------------*/
 
 gint
-utl_get_link_type (gchar *link) {
+utl_get_link_type (gchar *link)
+{
+	gint i, n;
 
-gint i, n;
+	g_return_val_if_fail (link != NULL, UNKNOWN);
 
-    for (i=n=0; i < strlen(link); i++) {
-        if(link[i] == '@') n++;
-    }
-
-    if (!strncasecmp(link, "https://", 8) || !strncasecmp(link, "http://", 7) || !strncasecmp(link, "www", 3)) {
-        return WWW;
-    } else if (n == 1) {
-        return EMAIL;
-    } else {
-        return UNKNOWN;
-    }
+	for (i = n = 0; i < strlen (link); i++)
+		if (link[i] == '@') n++;
 
+	if (!strncasecmp (link, "https://", 8) || !strncasecmp (link, "http://", 7) || !strncasecmp(link, "www", 3)) return WWW;
+	else if (n == 1) return EMAIL;
+	else return UNKNOWN;
 }
 
 /*------------------------------------------------------------------------------*/
