@@ -33,9 +33,11 @@ enum helpers {
 };
 
 gchar *     utl_text_replace                    (const gchar *text, const gchar *regex, const gchar *replacement);
+gchar *     utl_text_to_html                    (const gchar *text, gboolean ignoreBR);
 gchar *     utl_get_day_name                    (guint day, gboolean short_name);
 gchar *     utl_get_julian_day_name             (guint32 julian);
 gchar *     utl_get_date_name                   (const GDate *date);
+gchar *     utl_get_date_name_format            (const GDate *date, gchar *fmt);
 guint       utl_get_weekend_days_in_month       (const GDate *date);
 guint       utl_get_weekend_days_in_month_my    (guint month, guint year);
 guint       utl_get_days_per_year               (guint year);
